# Llama Stack CI

Llama Stack uses GitHub Actions for Continous Integration (CI). Below is a table detailing what CI the project includes and the purpose.

| Name | File | Purpose |
| ---- | ---- | ------- |
| Update Changelog | [changelog.yml](changelog.yml) | Creates PRs for updating the [CHANGELOG.md](../../CHANGELOG.md) |
| Coverage Badge | [coverage-badge.yml](coverage-badge.yml) | Creates PRs for updating the code coverage badge |
| Installer CI | [install-script-ci.yml](install-script-ci.yml) | Tests the [installation script](../../scripts/install.sh) |
| Integration Tests | [integration-tests.yml](integration-tests.yml) | Runs the [integration test suite](../../tests/integration/README.md) with Ollama |
| Integration Vector IO Tests | [integration-vector-io-tests.yml](integration-vector-io-tests.yml) | Runs the [integration test suite](../../tests/integration/README.md) with various VectorIO providers |
| Integration Auth Tests | [integration-auth-tests.yml](integration-auth-tests.yml) | Runs the [integration test suite](../../tests/integration/README.md) with Kubernetes authentication |
| Integration SQL Store Tests | [integration-sql-store-tests.yml](integration-sql-store-tests.yml) | Runs the [integration test suite](../../tests/integration/README.md) with SqlStore |
| Pre-commit | [pre-commit.yml](pre-commit.yml) | Runs pre-commit checks |
| Providers Build | [providers-build.yml](providers-build.yml) | Tests `llama stack build` |
| Python Build Test | [python-build-test.yml](python-build-test.yml) | Tests building the `llama-stack` PyPI project |
| Semantic PR | [semantic-pr.yml](semantic-pr.yml) | Ensures that PR titles follow the [conventional commit spec](https://www.conventionalcommits.org/en/v1.0.0/) |
| Stale Bot | [stale_bot.yml](stale_bot.yml) | Runs the [Stale Bot action](https://github.com/actions/stale) |
| Test External Providers | [test-external-providers.yml](test-external-providers.yml) | Tests the External Provider mechanism |
| Unit Tests | [unit-tests.yml](unit-tests.yml) | Runs the [unit test suite](../../tests/unit/README.md) |
| Update ReadTheDocs | [update-readthedocs.yml](update-readthedocs.yml) | Updates the Llama Stack [ReadTheDocs](https://readthedocs.org) site |
